@@ -2,29 +2,18 @@ import hashlib
 import math
 import time
 from datetime import datetime, timezone
-from enum import Enum
 from python_graphql_client import GraphqlClient
 
 
+from .const import API_KEY, API_SECRET, ENDPOINT
 from .exception_classes import LoginError
+from .status import NormalStatus, YesOrNo
+
 
 from . import gql_mutations as gm
 from . import gql_queries as gq
 
 
-class NormalStatus(Enum):
-    ENABLE = "ENABLE"
-    DISABLE = "DISABLE"
-    UNKNOWN__ = "UNKNOWN__"
-
-
-class WatchOnlineStatus(Enum):
-    UNKNOWN = "UNKNOWN"
-    ONLINE = "ONLINE"
-    OFFLINE = "OFFLINE"
-    UNKNOWN__ = "UNKNOWN__"
-
-
 class GQLHandler:
     def __init__(self, countryPhoneNumber: str, phoneNumber: str, password: str, userLang: str, timeZone: str):
         # init vars
@@ -36,12 +25,11 @@ class GQLHandler:
         self.countryPhoneNumber = countryPhoneNumber
         self.phoneNumber = phoneNumber
         self.passwordMD5 = hashlib.md5(password.encode()).hexdigest()
-        self.API_KEY = "270072d0fb4811ebacd96f6726fbdbb1"
-        self.API_SECRET = "2d0288d0fb4811ebabfbd57e57c6ae64"
+        self._API_KEY = API_KEY
+        self._API_SECRET = API_SECRET
         self.issueDate = 0
         self.expireDate = 0
         self.userId = None
-        self.ENDPOINT = "https://api.myxplora.com/api"
         self.variables = {
             "countryPhoneNumber": self.countryPhoneNumber,
             "phoneNumber": self.phoneNumber,
@@ -54,17 +42,17 @@ class GQLHandler:
     def getRequestHeaders(self, acceptedContentType: str):
         if acceptedContentType == "" or acceptedContentType is None:
             raise Exception("acceptedContentType MUST NOT be empty!")
-        if self.API_KEY is None:
+        if self._API_KEY is None:
             raise Exception("Xplorao2o API_KEY MUST NOT be empty!")
-        if self.API_SECRET is None:
+        if self._API_SECRET is None:
             raise Exception("Xplorao2o API_SECRET MUST NOT be empty!")
         requestHeaders = {}
         if self.accessToken is None:
             # OPEN authorization
-            authorizationHeader = f"Open {self.API_KEY}:{self.API_SECRET}"
+            authorizationHeader = f"Open {self._API_KEY}:{self._API_SECRET}"
         else:
             # BEARER authorization
-            authorizationHeader = f"Bearer {self.accessToken}:{self.API_SECRET}"
+            authorizationHeader = f"Bearer {self.accessToken}:{self._API_SECRET}"
             rfc1123DateString = datetime.now(timezone.utc).strftime("%a, %d %b %Y %H:%M:%S") + " GMT"
             requestHeaders["H-Date"] = rfc1123DateString
             requestHeaders["H-Authorization"] = authorizationHeader
@@ -80,7 +68,7 @@ class GQLHandler:
         # Add Xplora® API headers
         requestHeaders = self.getRequestHeaders("application/json; charset=UTF-8")
         # create GQLClient
-        gqlClient = GraphqlClient(endpoint=self.ENDPOINT, headers=requestHeaders)
+        gqlClient = GraphqlClient(endpoint=ENDPOINT, headers=requestHeaders)
         # execute QUERY|MUTATION
         data = gqlClient.execute(query=query, variables=variables)
         return data
@@ -92,7 +80,7 @@ class GQLHandler:
         return self.runGqlQuery(query, variables)
 
     def login(self):
-        data = self.runGqlQuery(gm.MUTATION["tokenM"], self.variables)['data']
+        data = self.runGqlQuery(gm.SIGN_M["issueTokenM"], self.variables)['data']
         if data['issueToken'] is None:
             # Login failed.
             raise LoginError("Login to Xplora® API failed. Check your input!")
@@ -108,9 +96,9 @@ class GQLHandler:
         if self.issueToken['app'] is not None:
             # Update API_KEY and API_SECRET?
             if self.issueToken['app']['apiKey']:
-                self.API_KEY = self.issueToken['app']['apiKey']
+                self._API_KEY = self.issueToken['app']['apiKey']
             if self.issueToken['app']['apiSecret']:
-                self.API_SECRET = self.issueToken['app']['apiSecret']
+                self._API_SECRET = self.issueToken['app']['apiSecret']
         return self.issueToken
 
     def isAdmin(self, ownId, query, variables, key):
@@ -129,80 +117,76 @@ class GQLHandler:
 
     def getMyInfo(self):
         # Profil from login Account
-        return self.runAuthorizedGqlQuery(gq.QUERY['readMyInfoQ'], {})['data']
+        return self.runAuthorizedGqlQuery(gq.MYINFO_Q['readQ'], {})['data']
 
     def getContacts(self, ownId):
         # Contacts from ownUser
-        return self.runAuthorizedGqlQuery(gq.QUERY['contactsQ'], { "uid": ownId })['data']
+        return self.runAuthorizedGqlQuery(gq.WATCH_Q['contactsQ'], { "uid": ownId })['data']
 
     def getWatchCount(self):
-        return self.runAuthorizedGqlQuery(gq.QUERY['watchCountQ'], {})['data']
+        return self.runAuthorizedGqlQuery(gq.QUERY['followRequestWatchCountQ'], {})['data']
 
     def getWatches(self, ownId):
-        return self.runAuthorizedGqlQuery(gq.QUERY['watchesQ'], { "uid": ownId })['data']
+        return self.runAuthorizedGqlQuery(gq.WATCH_Q['watchesQ'], { "uid": ownId })['data']
 
     def getWatchLastLocation(self, ownId):
-        return self.runAuthorizedGqlQuery(gq.QUERY['watchLastLocateQ'], { "uid": ownId })['data']
+        return self.runAuthorizedGqlQuery(gq.WATCH_Q['locateQ'], { "uid": ownId })['data']
 
     def trackWatch(self, ownId):
         # tracking time - seconds
-        res = self.runAuthorizedGqlQuery(gq.QUERY['trackWatchQ'], { "uid": ownId })['data']
+        res = self.runAuthorizedGqlQuery(gq.WATCH_Q['trackQ'], { "uid": ownId })['data']
         if res['trackWatch'] is not None:
             return res
         return { 'trackWatch': -1 }
 
     def askWatchLocate(self, ownId):
-        res = self.runAuthorizedGqlQuery(gq.QUERY['askWatchLocateQ'], { "uid": ownId })['data']
+        res = self.runAuthorizedGqlQuery(gq.WATCH_Q['askLocateQ'], { "uid": ownId })['data']
         if res['askWatchLocate'] is not None:
             return res
         return { 'askWatchLocate': False }
 
     def getAlarms(self, ownId):
-        return self.runAuthorizedGqlQuery(gq.QUERY['alarmsQ'], { "uid": ownId })['data']
+        return self.runAuthorizedGqlQuery(gq.WATCH_Q['alarmsQ'], { "uid": ownId })['data']
 
     def getWifi(self, id):
         # without function?
-        return self.runAuthorizedGqlQuery(gq.QUERY['getWifiQ'], { "uid": id })['data']
+        return self.runAuthorizedGqlQuery(gq.WATCH_Q['getWifisQ'], { "uid": id })['data']
 
     def avatars(self, id):
         # without function?
-        return self.runAuthorizedGqlQuery(gq.QUERY['avatarsQ'], { 'id': id })['data']
+        return self.runAuthorizedGqlQuery(gq.CAMPAIGN_Q['avatarsQ'], { 'id': id })['data']
 
     def unReadChatMsgCount(self, ownId):
-        return self.runAuthorizedGqlQuery(gq.QUERY['unReadChatMsgCountQ'], { 'uid': ownId })['data']
+        return self.runAuthorizedGqlQuery(gq.WATCH_Q['unReadChatMsgCountQ'], { 'uid': ownId })['data']
 
     def chats(self, ownId):
         # ownUser id
-        return self.runAuthorizedGqlQuery(gq.QUERY['chatsQ'], { 'uid': ownId })['data']
-
-    def notice(self):
-        # without function?
-        return self.runAuthorizedGqlQuery(gq.QUERY['noticeQ'], {})['data']
+        return self.runAuthorizedGqlQuery(gq.WATCH_Q['chatsQ'], { 'uid': ownId })['data']
 
     def staticCard(self):
-        return self.runAuthorizedGqlQuery(gq.QUERY['staticCardQ'], {})['data']
+        return self.runAuthorizedGqlQuery(gq.CARD_Q['staticQ'], {})['data']
 
     def campaignUserProfiles(self):
-        return self.runAuthorizedGqlQuery(gq.QUERY['CampaignUserProfilesQ'], {})['data']
+        return self.runAuthorizedGqlQuery(gq.MYINFO_Q['campaignUserProfilesQ'], {})['data']
 
     def subscribedCampaign(self, id, needDetail=False):
-        return self.runAuthorizedGqlQuery(gq.QUERY['subscribedCampaignQ'], { 'uid': id, 'needDetail': needDetail })['data']
+        return self.runAuthorizedGqlQuery(gq.CAMPAIGN_Q['subscribedQ'], { 'uid': id, 'needDetail': needDetail })['data']
 
     def getReviewStatus(self, id):
-        return self.runAuthorizedGqlQuery(gq.QUERY['GetReviewStatusQ'], { 'uid': id })['data']
+        return self.runAuthorizedGqlQuery(gq.REVIEW_Q['getStatusQ'], { 'uid': id })['data']
 
     def countries(self):
         # Country Support
-        return self.runAuthorizedGqlQuery(gq.QUERY['CountriesQ'], {})['data']
+        return self.runAuthorizedGqlQuery(gq.UTILS_Q['countriesQ'], {})['data']
 
     def safeZones(self, ownId):
-        return self.runAuthorizedGqlQuery(gq.QUERY['safeZonesQ'], { 'uid': ownId })['data']
+        return self.runAuthorizedGqlQuery(gq.WATCH_Q['safeZonesQ'], { 'uid': ownId })['data']
 
     def safeZoneGroups(self):
-        return self.runAuthorizedGqlQuery(gq.QUERY['safeZoneGroupsQ'], {})['data']
+        return self.runAuthorizedGqlQuery(gq.WATCH_Q['safeZoneGroupsQ'], {})['data']
 
     def silentTimes(self, ownId):
-        return self.runAuthorizedGqlQuery(gq.QUERY['silentTimesQ'], { 'uid': ownId })['data']
+        return self.runAuthorizedGqlQuery(gq.WATCH_Q['silentTimesQ'], { 'uid': ownId })['data']
 
 ########## SECTION QUERY end ##########
 
@@ -210,32 +194,32 @@ class GQLHandler:
 
     def sendText(self, ownId, text):
         # ownUser id
-        if self.runAuthorizedGqlQuery(gm.MUTATION['sendTextM'], { "uid": ownId, "text": text })['data']['sendChatText'] is not None:
+        if self.runAuthorizedGqlQuery(gm.WATCH_M['sendChatTextM'], { "uid": ownId, "text": text })['data']['sendChatText'] is not None:
             return True
         return False
 
     def addStep(self, stepCount):
-        return self.runAuthorizedGqlQuery(gm.MUTATION['addStepM'], { "stepCount": stepCount })['data']
+        return self.runAuthorizedGqlQuery(gm.STEP_M['addM'], { "stepCount": stepCount })['data']
 
     def shutdown(self, ownId):
         # ownUser id
-        return self.isAdmin(ownId, gm.MUTATION['shutdownM'], { "uid": ownId }, 'reboot')
+        return self.isAdmin(ownId, gm.WATCH_M['shutdownM'], { "uid": ownId }, 'reboot')
 
     def reboot(self, ownId):
         # ownUser id
-        return self.isAdmin(ownId, gm.MUTATION['rebootM'], { "uid": ownId }, 'reboot')
+        return self.isAdmin(ownId, gm.WATCH_M['rebootM'], { "uid": ownId }, 'reboot')
 
-    def modifyAlert(self, id, YesOrNo):
+    def modifyAlert(self, id, yesOrNo: YesOrNo):
         # function?
-        return self.runAuthorizedGqlQuery(gm.MUTATION['modifyAlertM'], { "uid": id, "remind": YesOrNo })
+        return self.runAuthorizedGqlQuery(gm.WATCH_M['modifyAlertM'], { "uid": id, "remind": yesOrNo })
 
     def setEnableSlientTime(self, silentId, status: NormalStatus = NormalStatus.ENABLE.value):
-        return self.runAuthorizedGqlQuery(gm.MUTATION['setEnableSlientTimeM'], { 'silentId': silentId, 'status': status })['data']
+        return self.runAuthorizedGqlQuery(gm.WATCH_M['setEnableSlientTimeM'], { 'silentId': silentId, 'status': status })['data']
 
     def setEnableAlarmTime(self, alarmId, status: NormalStatus = NormalStatus.ENABLE.value):
-        return self.runAuthorizedGqlQuery(gm.MUTATION['ModifyAlarmM'], { 'alarmId': alarmId, 'status': status })['data']
+        return self.runAuthorizedGqlQuery(gm.WATCH_M['modifyAlarmM'], { 'alarmId': alarmId, 'status': status })['data']
 
     def setReadChatMsg(self, ownId, msgId, id):
-        return self.runAuthorizedGqlQuery(gm.MUTATION['setReadChatMsg'], { "uid": ownId, 'msgId': msgId, 'id': id })['data']
+        return self.runAuthorizedGqlQuery(gm.WATCH_M['setReadChatMsgM'], { "uid": ownId, 'msgId': msgId, 'id': id })['data']
 
 ########## SECTION MUTATION end ##########
